==> matrix_sdk-0.25.1.tar.gz: test/local_user_test.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

import 'dart:convert';

import 'package:http/http.dart';
import 'package:http/testing.dart';
import 'package:matrix_sdk/matrix_sdk.dart';
import 'package:test/test.dart';
import 'package:url/url.dart';

void testLocalUser() {
  group('LocalUser', () {
    group('.stopSync ', () {
      test('stops sync process', () async {
        final hs = Homeserver(
          Url.parse('https://pattle.im'),
          httpClient: MockClient((request) async {
            if (request.url.path.endsWith('login')) {
              return Response(
                json.encode({
                  'user_id': '@pat:pattle.im',
                  'access_token': 'abc123',
                  'device_id': 'GHTYAJCE',
                  'well_known': {
                    'm.homeserver': {
                      'base_url': 'https://pattle.im',
                    },
                    'm.identity_server': {
                      'base_url': 'https://id.pattle.im',
                    },
                  },
                }),
                200,
              );
            } else {
              return Response(
                """
                {
                  "next_batch": "s72595_4483_1934",
                  "presence": {
                    "events": [
                      {
                        "content": {
                          "avatar_url": "mxc://localhost:wefuiwegh8742w",
                          "last_active_ago": 2478593,
                          "presence": "online",
                          "currently_active": false,
                          "status_msg": "Making cupcakes"
                        },
                        "type": "m.presence",
                        "sender": "@example:localhost"
                      }
                    ]
                  },
                  "account_data": {
                    "events": [
                      {
                        "type": "org.example.custom.config",
                        "content": {
                          "custom_config_key": "custom_config_value"
                        }
                      }
                    ]
                  },
                  "rooms": {
                    "join": {
                      "!726s6s6q:example.com": {
                        "summary": {
                          "m.heroes": [
                            "@alice:example.com",
                            "@bob:example.com"
                          ],
                          "m.joined_member_count": 2,
                          "m.invited_member_count": 0
                        },
                        "state": {
                          "events": [
                            {
                              "content": {
                                "membership": "join",
                                "avatar_url": "mxc://example.org/SEsfnsuifSDFSSEF",
                                "displayname": "Alice Margatroid"
                              },
                              "type": "m.room.member",
                              "event_id": "\$143273582443PhrSn:example.org",
                              "room_id": "!726s6s6q:example.com",
                              "sender": "@example:example.org",
                              "origin_server_ts": 1432735824653,
                              "unsigned": {
                                "age": 1234
                              },
                              "state_key": "@alice:example.org"
                            }
                          ]
                        },
                        "timeline": {
                          "events": [
                            {
                              "content": {
                                "membership": "join",
                                "avatar_url": "mxc://example.org/SEsfnsuifSDFSSEF",
                                "displayname": "Alice Margatroid"
                              },
                              "type": "m.room.member",
                              "event_id": "\$143273582443PhrSn:example.org",
                              "room_id": "!726s6s6q:example.com",
                              "sender": "@example:example.org",
                              "origin_server_ts": 1432735824653,
                              "unsigned": {
                                "age": 1234
                              },
                              "state_key": "@alice:example.org"
                            },
                            {
                              "content": {
                                "body": "This is an example text message",
                                "msgtype": "m.text",
                                "format": "org.matrix.custom.html",
                                "formatted_body": "<b>This is an example text message</b>"
                              },
                              "type": "m.room.message",
                              "event_id": "\$143273582443PhrSn:example.org",
                              "room_id": "!726s6s6q:example.com",
                              "sender": "@example:example.org",
                              "origin_server_ts": 1432735824653,
                              "unsigned": {
                                "age": 1234
                              }
                            }
                          ],
                          "limited": true,
                          "prev_batch": "t34-23535_0_0"
                        },
                        "ephemeral": {
                          "events": [
                            {
                              "content": {
                                "user_ids": [
                                  "@alice:matrix.org",
                                  "@bob:example.com"
                                ]
                              },
                              "type": "m.typing",
                              "room_id": "!jEsUZKDJdhlrceRyVU:example.org"
                            }
                          ]
                        },
                        "account_data": {
                          "events": [
                            {
                              "content": {
                                "tags": {
                                  "u.work": {
                                    "order": 0.9
                                  }
                                }
                              },
                              "type": "m.tag"
                            },
                            {
                              "type": "org.example.custom.room.config",
                              "content": {
                                "custom_config_key": "custom_config_value"
                              }
                            }
                          ]
                        }
                      }
                    },
                    "invite": {
                      "!696r7674:example.com": {
                        "invite_state": {
                          "events": [
                            {
                              "sender": "@alice:example.com",
                              "type": "m.room.name",
                              "state_key": "",
                              "content": {
                                "name": "My Room Name"
                              }
                            },
                            {
                              "sender": "@alice:example.com",
                              "type": "m.room.member",
                              "state_key": "@bob:example.com",
                              "content": {
                                "membership": "invite"
                              }
                            }
                          ]
                        }
                      }
                    },
                    "leave": {}
                  }
                }

                """,
                200,
              );
            }
          }),
        );

        final user = await hs.login(
          Username('pat'),
          'password',
          store: MemoryStore(),
        );

        await for (var _ in user.sync()) {
          expect(user.isSyncing, isTrue);
          user.stopSync();
        }

        expect(user.isSyncing, isFalse);
      });
    });
  });
}

// TODO: Handle 400

==> matrix_sdk-0.26.0.tar.gz: test/local_user_test.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

import 'dart:async';
import 'dart:convert';

import 'package:http/http.dart';
import 'package:http/testing.dart';
import 'package:matrix_sdk/matrix_sdk.dart';
import 'package:test/test.dart';
import 'package:url/url.dart';

void testLocalUser() {
  group('LocalUser', () {
    Homeserver hs;
    LocalUser user;

    setUp(() async {
      hs = Homeserver(
        Url.parse('https://pattle.im'),
        httpClient: MockClient((request) async {
          if (request.url.path.endsWith('login')) {
            return Response(
              json.encode({
                'user_id': '@pat:pattle.im',
                'access_token': 'abc123',
                'device_id': 'GHTYAJCE',
                'well_known': {
                  'm.homeserver': {
                    'base_url': 'https://pattle.im',
                  },
                  'm.identity_server': {
                    'base_url': 'https://id.pattle.im',
                  },
                },
              }),
              200,
            );
          } else {
            return Response(
              """
                {
                  "next_batch": "s72595_4483_1934",
                  "presence": {
                    "events": [
                      {
                        "content": {
                          "avatar_url": "mxc://localhost:wefuiwegh8742w",
                          "last_active_ago": 2478593,
                          "presence": "online",
                          "currently_active": false,
                          "status_msg": "Making cupcakes"
                        },
                        "type": "m.presence",
                        "sender": "@example:localhost"
                      }
                    ]
                  },
                  "account_data": {
                    "events": [
                      {
                        "type": "org.example.custom.config",
                        "content": {
                          "custom_config_key": "custom_config_value"
                        }
                      }
                    ]
                  },
                  "rooms": {
                    "join": {
                      "!726s6s6q:example.com": {
                        "summary": {
                          "m.heroes": [
                            "@alice:example.com",
                            "@bob:example.com"
                          ],
                          "m.joined_member_count": 2,
                          "m.invited_member_count": 0
                        },
                        "state": {
                          "events": [
                            {
                              "content": {
                                "membership": "join",
                                "avatar_url": "mxc://example.org/SEsfnsuifSDFSSEF",
                                "displayname": "Alice Margatroid"
                              },
                              "type": "m.room.member",
                              "event_id": "\$143273582443PhrSn:example.org",
                              "room_id": "!726s6s6q:example.com",
                              "sender": "@example:example.org",
                              "origin_server_ts": 1432735824653,
                              "unsigned": {
                                "age": 1234
                              },
                              "state_key": "@alice:example.org"
                            }
                          ]
                        },
                        "timeline": {
                          "events": [
                            {
                              "content": {
                                "membership": "join",
                                "avatar_url": "mxc://example.org/SEsfnsuifSDFSSEF",
                                "displayname": "Alice Margatroid"
                              },
                              "type": "m.room.member",
                              "event_id": "\$143273582443PhrSn:example.org",
                              "room_id": "!726s6s6q:example.com",
                              "sender": "@example:example.org",
                              "origin_server_ts": 1432735824653,
                              "unsigned": {
                                "age": 1234
                              },
                              "state_key": "@alice:example.org"
                            },
                            {
                              "content": {
                                "body": "This is an example text message",
                                "msgtype": "m.text",
                                "format": "org.matrix.custom.html",
                                "formatted_body": "<b>This is an example text message</b>"
                              },
                              "type": "m.room.message",
                              "event_id": "\$143273582443PhrSn:example.org",
                              "room_id": "!726s6s6q:example.com",
                              "sender": "@example:example.org",
                              "origin_server_ts": 1432735824653,
                              "unsigned": {
                                "age": 1234
                              }
                            }
                          ],
                          "limited": true,
                          "prev_batch": "t34-23535_0_0"
                        },
                        "ephemeral": {
                          "events": [
                            {
                              "content": {
                                "user_ids": [
                                  "@alice:matrix.org",
                                  "@bob:example.com"
                                ]
                              },
                              "type": "m.typing",
                              "room_id": "!jEsUZKDJdhlrceRyVU:example.org"
                            }
                          ]
                        },
                        "account_data": {
                          "events": [
                            {
                              "content": {
                                "tags": {
                                  "u.work": {
                                    "order": 0.9
                                  }
                                }
                              },
                              "type": "m.tag"
                            },
                            {
                              "type": "org.example.custom.room.config",
                              "content": {
                                "custom_config_key": "custom_config_value"
                              }
                            }
                          ]
                        }
                      }
                    },
                    "invite": {
                      "!696r7674:example.com": {
                        "invite_state": {
                          "events": [
                            {
                              "sender": "@alice:example.com",
                              "type": "m.room.name",
                              "state_key": "",
                              "content": {
                                "name": "My Room Name"
                              }
                            },
                            {
                              "sender": "@alice:example.com",
                              "type": "m.room.member",
                              "state_key": "@bob:example.com",
                              "content": {
                                "membership": "invite"
                              }
                            }
                          ]
                        }
                      }
                    },
                    "leave": {}
                  }
                }

                """,
              200,
            );
          }
        }),
      );
      user = await hs.login(
        Username('pat'),
        'password',
        store: MemoryStore(),
      );
    });

    test('stops sync process', () async {
      StreamSubscription sub;
      sub = user.sync.listen((_) {
        expect(user.isSyncing, isTrue);
        user.stopSync();
        expect(user.isSyncing, isFalse);

        sub.cancel();
      });

      await user.startSync();
    });

    test('.rooms update Stream delivers correct rooms', () async {
      StreamSubscription sub;
      sub = user.rooms.updates.listen((rooms) {
        final room = rooms.first;

        expect(room.id, RoomId('!726s6s6q:example.com'));
        expect(room.members.count, 2);

        user.stopSync();
        sub.cancel();
      });

      await user.startSync();
    });
  });
}

// TODO: Handle 400
